pub fn has_meaningful_headers(expected: &HttpExpectedResponse) -> boolExpand description
Whether the expected-response carries any header expectations beyond content-encoding (which the mock layer strips and is therefore not asserted).
pub fn has_meaningful_headers(expected: &HttpExpectedResponse) -> boolWhether the expected-response carries any header expectations beyond content-encoding (which the mock layer strips and is therefore not asserted).