HTTP integration test generation for Rust e2e tests.
Functions
- render_
cors_ layer - Emit lines that wrap the axum router with a
tower_http::cors::CorsLayer. - render_
http_ test_ function - Generate a complete integration test function for an http fixture.