Module format

Module format 

Post-generation formatter support for e2e test projects.

Reads formatter commands from E2eConfig.format and runs them for each language that had files generated. The {dir} placeholder in the command is replaced with the actual output directory.

Functions

run_formatters
Run per-language formatters for all languages that had files generated.