Module validate

Module validate 

JSON Schema validation for e2e fixture files.

Structs

ValidationError
A validation error with its source file and message.

Functions

validate_fixtures
Validate all JSON fixture files in a directory against the fixture schema.