pub struct ValidationError {
pub file: String,
pub message: String,
pub severity: Severity,
}Expand description
A validation error with its source file and message.
Fields
file: StringRelative path of the fixture file that failed validation.
message: StringHuman-readable error message.
severity: SeveritySeverity level.