Module http

Module http 

HTTP integration test generation for Rust e2e tests.

Functions

render_cors_layer
Emit lines that wrap the axum router with a tower_http::cors::CorsLayer.
render_http_test_function
Generate a complete integration test function for an http fixture.