Module swift

Module swift 

Swift e2e test generator using XCTest.

Generates test files for the swift package in packages/swift/Tests/<Module>Tests/.

IMPORTANT: Due to SwiftPM 6.0 limitations (forbids inter-package .package(path:) references within a monorepo), generated test files are placed directly inside the packages/swift package (not in a separate e2e/swift package). This allows tests to depend on the library target without an explicit package dependency.

The generated Package.swift is placed in e2e/swift/ for documentation and CI reference but is NOT used for running tests — tests are run from the packages/swift/ directory using swift test.

Structs

SwiftE2eCodegen
Swift e2e code generator.