run_formatters

Function run_formatters 

pub fn run_formatters(files: &[GeneratedFile], e2e_config: &E2eConfig)
Run per-language formatters for all languages that had files generated.

For each language present in files, looks up e2e_config.format[lang] and runs the command with {dir} replaced by {output}/{lang}. Failures are logged as warnings and do not abort the process.